@@ -12,12 +12,99 @@ use Scalar::Util;
 use Type::Library -base;
 use Type::Utils   -all;
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 extends 'Types::Standard';
 extends 'Types::Common::Numeric';
 extends 'Types::Common::String';
 
+our @TYPES = qw(
+    Any
+    AnyObj
+    AnyObject
+    ArrayObj
+    ArrayObject
+    ArrayRef
+    Bool
+    ClassName
+    CodeObj
+    CodeObject
+    CodeRef
+    ConsumerOf
+    Defined
+    Dict
+    Enum
+    FileHandle
+    FloatObj
+    FloatObject
+    GlobRef
+    HasMethods
+    HashObj
+    HashObject
+    HashRef
+    InstanceOf
+    Int
+    IntObj
+    IntObject
+    IntegerObj
+    IntegerObject
+    Item
+    LaxNum
+    LowerCaseSimpleStr
+    LowerCaseStr
+    Map
+    Maybe
+    NegativeInt
+    NegativeNum
+    NegativeOrZeroInt
+    NegativeOrZeroNum
+    NonEmptySimpleStr
+    NonEmptyStr
+    Num
+    NumObj
+    NumObject
+    NumberObj
+    NumberObject
+    NumericCode
+    Object
+    OptList
+    Optional
+    Overload
+    Password
+    PositiveInt
+    PositiveNum
+    PositiveOrZeroInt
+    PositiveOrZeroNum
+    Ref
+    RegexpObj
+    RegexpObject
+    RegexpRef
+    RoleName
+    ScalarObj
+    ScalarObject
+    ScalarRef
+    SimpleStr
+    SingleDigit
+    Str
+    StrMatch
+    StrObj
+    StrObject
+    StrictNum
+    StringObj
+    StringObject
+    StrongPassword
+    Tied
+    Tuple
+    Undef
+    UndefObj
+    UndefObject
+    UniversalObj
+    UniversalObject
+    UpperCaseSimpleStr
+    UpperCaseStr
+    Value
+);
+
 my $registry = __PACKAGE__->meta;
 
 sub DECLARE {
@@ -357,7 +444,7 @@ Data::Object::Library - Type Library for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
@@ -373,7 +460,10 @@ libraries and adds type constraints and coercions for L<Data::Object> objects.
 
 =head2 Any
 
-    has data => (isa => Any);
+    has data => (
+        is  => 'rw',
+        isa => Any,
+    );
 
 The Any type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Any> function can be
@@ -383,7 +473,10 @@ validated.
 
 =head2 AnyObj
 
-    has data => (isa => AnyObj);
+    has data => (
+        is  => 'rw',
+        isa => AnyObj,
+    );
 
 The AnyObj type constraint is provided by this library and accepts any object
 that is, or is derived from, a L<Data::Object::Universal> object. The
@@ -393,7 +486,10 @@ the argument can not be validated.
 
 =head2 AnyObject
 
-    has data => (isa => AnyObject);
+    has data => (
+        is  => 'rw',
+        isa => AnyObject,
+    );
 
 The AnyObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Universal> object. The
@@ -403,7 +499,10 @@ if the argument can not be validated.
 
 =head2 ArrayObj
 
-    has data => (isa => ArrayObj);
+    has data => (
+        is  => 'rw',
+        isa => ArrayObj,
+    );
 
 The ArrayObj type constraint is provided by this library and accepts any object
 that is, or is derived from, a L<Data::Object::Array> object. The
@@ -413,7 +512,10 @@ if the argument can not be validated.
 
 =head2 ArrayObject
 
-    has data => (isa => ArrayObject);
+    has data => (
+        is  => 'rw',
+        isa => ArrayObject,
+    );
 
 The ArrayObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Array> object. The
@@ -423,7 +525,10 @@ false if the argument can not be validated.
 
 =head2 ArrayRef
 
-    has data => (isa => ArrayRef);
+    has data => (
+        is  => 'rw',
+        isa => ArrayRef,
+    );
 
 The ArrayRef type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_ArrayRef
@@ -433,7 +538,10 @@ argument can not be validated.
 
 =head2 Bool
 
-    has data => (isa => Bool);
+    has data => (
+        is  => 'rw',
+        isa => Bool,
+    );
 
 The Bool type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Bool> function can be
@@ -443,7 +551,10 @@ validated.
 
 =head2 ClassName
 
-    has data => (isa => ClassName['MyClass']);
+    has data => (
+        is  => 'rw',
+        isa => ClassName['MyClass'],
+    );
 
 The ClassName type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_ClassName
@@ -453,7 +564,10 @@ argument can not be validated.
 
 =head2 CodeObj
 
-    has data => (isa => CodeObj);
+    has data => (
+        is  => 'rw',
+        isa => CodeObj,
+    );
 
 The CodeObj type constraint is provided by this library and accepts any object
 that is, or is derived from, a L<Data::Object::Code> object. The C<assert_CodeObj
@@ -463,7 +577,10 @@ argument can not be validated.
 
 =head2 CodeObject
 
-    has data => (isa => CodeObject);
+    has data => (
+        is  => 'rw',
+        isa => CodeObject,
+    );
 
 The CodeObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Code> object. The
@@ -473,7 +590,10 @@ false if the argument can not be validated.
 
 =head2 CodeRef
 
-    has data => (isa => CodeRef);
+    has data => (
+        is  => 'rw',
+        isa => CodeRef,
+    );
 
 The CodeRef type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_CodeRef> function
@@ -483,7 +603,10 @@ be validated.
 
 =head2 ConsumerOf
 
-    has data => (isa => ConsumerOf['MyRole']);
+    has data => (
+        is  => 'rw',
+        isa => ConsumerOf['MyRole'],
+    );
 
 The ConsumerOf type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_ConsumerOf
@@ -493,7 +616,10 @@ the argument can not be validated.
 
 =head2 Defined
 
-    has data => (isa => Defined);
+    has data => (
+        is  => 'rw',
+        isa => Defined,
+    );
 
 The Defined type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_Defined> function
@@ -503,7 +629,10 @@ be validated.
 
 =head2 Dict
 
-    has data => (isa => Dict);
+    has data => (
+        is  => 'rw',
+        isa => Dict,
+    );
 
 The Dict type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Dict> function can be
@@ -513,7 +642,10 @@ validated.
 
 =head2 Enum
 
-    has data => (isa => Enum);
+    has data => (
+        is  => 'rw',
+        isa => Enum,
+    );
 
 The Enum type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Enum> function can be
@@ -523,7 +655,10 @@ validated.
 
 =head2 FileHandle
 
-    has data => (isa => FileHandle);
+    has data => (
+        is  => 'rw',
+        isa => FileHandle,
+    );
 
 The FileHandle type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_FileHandle
@@ -533,7 +668,10 @@ the argument can not be validated.
 
 =head2 FloatObj
 
-    has data => (isa => FloatObj);
+    has data => (
+        is  => 'rw',
+        isa => FloatObj,
+    );
 
 The FloatObj type constraint is provided by this library and accepts any object
 that is, or is derived from, a L<Data::Object::Float> object. The
@@ -543,7 +681,10 @@ if the argument can not be validated.
 
 =head2 FloatObject
 
-    has data => (isa => FloatObject);
+    has data => (
+        is  => 'rw',
+        isa => FloatObject,
+    );
 
 The FloatObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Float> object. The
@@ -553,7 +694,10 @@ false if the argument can not be validated.
 
 =head2 GlobRef
 
-    has data => (isa => GlobRef);
+    has data => (
+        is  => 'rw',
+        isa => GlobRef,
+    );
 
 The GlobRef type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_GlobRef> function
@@ -563,7 +707,10 @@ be validated.
 
 =head2 HasMethods
 
-    has data => (isa => HasMethods);
+    has data => (
+        is  => 'rw',
+        isa => HasMethods[...],
+    );
 
 The HasMethods type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_HasMethods
@@ -573,7 +720,10 @@ the argument can not be validated.
 
 =head2 HashObj
 
-    has data => (isa => HashObj);
+    has data => (
+        is  => 'rw',
+        isa => HashObj,
+    );
 
 The HashObj type constraint is provided by this library and accepts any object
 that is, or is derived from, a L<Data::Object::Hash> object. The C<assert_HashObj
@@ -583,7 +733,10 @@ argument can not be validated.
 
 =head2 HashObject
 
-    has data => (isa => HashObject);
+    has data => (
+        is  => 'rw',
+        isa => HashObject,
+    );
 
 The HashObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Hash> object. The
@@ -593,7 +746,10 @@ false if the argument can not be validated.
 
 =head2 HashRef
 
-    has data => (isa => HashRef);
+    has data => (
+        is  => 'rw',
+        isa => HashRef,
+    );
 
 The HashRef type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_HashRef> function
@@ -603,7 +759,10 @@ be validated.
 
 =head2 InstanceOf
 
-    has data => (isa => InstanceOf['MyClass']);
+    has data => (
+        is  => 'rw',
+        isa => InstanceOf['MyClass'],
+    );
 
 The InstanceOf type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_InstanceOf
@@ -613,7 +772,10 @@ the argument can not be validated.
 
 =head2 Int
 
-    has data => (isa => Int);
+    has data => (
+        is  => 'rw',
+        isa => Int,
+    );
 
 The Int type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Int> function can be
@@ -623,7 +785,10 @@ validated.
 
 =head2 IntObj
 
-    has data => (isa => IntObj);
+    has data => (
+        is  => 'rw',
+        isa => IntObj,
+    );
 
 The IntObj type constraint is provided by this library and accepts any object
 that is, or is derived from, a L<Data::Object::Integer> object. The
@@ -633,7 +798,10 @@ the argument can not be validated.
 
 =head2 IntObject
 
-    has data => (isa => IntObject);
+    has data => (
+        is  => 'rw',
+        isa => IntObject,
+    );
 
 The IntObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Integer> object. The
@@ -643,7 +811,10 @@ if the argument can not be validated.
 
 =head2 IntegerObj
 
-    has data => (isa => IntegerObj);
+    has data => (
+        is  => 'rw',
+        isa => IntegerObj,
+    );
 
 The IntegerObj type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Integer> object. The
@@ -653,7 +824,10 @@ false if the argument can not be validated.
 
 =head2 IntegerObject
 
-    has data => (isa => IntegerObject);
+    has data => (
+        is  => 'rw',
+        isa => IntegerObject,
+    );
 
 The IntegerObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Integer> object. The
@@ -663,7 +837,10 @@ or false if the argument can not be validated.
 
 =head2 Item
 
-    has data => (isa => Item);
+    has data => (
+        is  => 'rw',
+        isa => Item,
+    );
 
 The Item type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Item> function can be
@@ -673,7 +850,10 @@ validated.
 
 =head2 LaxNum
 
-    has data => (isa => LaxNum);
+    has data => (
+        is  => 'rw',
+        isa => LaxNum,
+    );
 
 The LaxNum type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_LaxNum> function
@@ -683,7 +863,10 @@ be validated.
 
 =head2 LowerCaseSimpleStr
 
-    has data => (isa => LowerCaseSimpleStr);
+    has data => (
+        is  => 'rw',
+        isa => LowerCaseSimpleStr,
+    );
 
 The LowerCaseSimpleStr type constraint is provided by the
 L<Types::Common::String> library. Please see that documentation for more The
@@ -694,7 +877,10 @@ information.
 
 =head2 LowerCaseStr
 
-    has data => (isa => LowerCaseStr);
+    has data => (
+        is  => 'rw',
+        isa => LowerCaseStr,
+    );
 
 The LowerCaseStr type constraint is provided by the L<Types::Common::String>
 library. Please see that documentation for more information. The C<assert_type
@@ -704,7 +890,10 @@ argument can not be validated.
 
 =head2 Map
 
-    has data => (isa => Map[Int, HashRef]);
+    has data => (
+        is  => 'rw',
+        isa => Map[Int, HashRef],
+    );
 
 The Map type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Map> function can be
@@ -714,7 +903,10 @@ validated.
 
 =head2 Maybe
 
-    has data => (isa => Maybe);
+    has data => (
+        is  => 'rw',
+        isa => Maybe,
+    );
 
 The Maybe type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Maybe> function can be
@@ -724,7 +916,10 @@ validated.
 
 =head2 NegativeInt
 
-    has data => (isa => NegativeInt);
+    has data => (
+        is  => 'rw',
+        isa => NegativeInt,
+    );
 
 The NegativeInt type constraint is provided by the L<Types::Common::Numeric>
 library. Please see that documentation for more information. The
@@ -734,7 +929,10 @@ false if the argument can not be validated.
 
 =head2 NegativeNum
 
-    has data => (isa => NegativeNum);
+    has data => (
+        is  => 'rw',
+        isa => NegativeNum,
+    );
 
 The NegativeNum type constraint is provided by the L<Types::Common::Numeric>
 library. Please see that documentation for more information. The
@@ -744,7 +942,10 @@ false if the argument can not be validated.
 
 =head2 NegativeOrZeroInt
 
-    has data => (isa => NegativeOrZeroInt);
+    has data => (
+        is  => 'rw',
+        isa => NegativeOrZeroInt,
+    );
 
 The NegativeOrZeroInt type constraint is provided by the
 L<Types::Common::Numeric> library. Please see that documentation for more The
@@ -755,7 +956,10 @@ information.
 
 =head2 NegativeOrZeroNum
 
-    has data => (isa => NegativeOrZeroNum);
+    has data => (
+        is  => 'rw',
+        isa => NegativeOrZeroNum,
+    );
 
 The NegativeOrZeroNum type constraint is provided by the
 L<Types::Common::Numeric> library. Please see that documentation for more The
@@ -766,7 +970,10 @@ information.
 
 =head2 NonEmptySimpleStr
 
-    has data => (isa => NonEmptySimpleStr);
+    has data => (
+        is  => 'rw',
+        isa => NonEmptySimpleStr,
+    );
 
 The NonEmptySimpleStr type constraint is provided by the
 L<Types::Common::String> library. Please see that documentation for more The
@@ -777,7 +984,10 @@ information.
 
 =head2 NonEmptyStr
 
-    has data => (isa => NonEmptyStr);
+    has data => (
+        is  => 'rw',
+        isa => NonEmptyStr,
+    );
 
 The NonEmptyStr type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_type> function
@@ -787,7 +997,10 @@ validated.
 
 =head2 Num
 
-    has data => (isa => Num);
+    has data => (
+        is  => 'rw',
+        isa => Num,
+    );
 
 The Num type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Num> function can be
@@ -797,7 +1010,10 @@ validated.
 
 =head2 NumObj
 
-    has data => (isa => NumObj);
+    has data => (
+        is  => 'rw',
+        isa => NumObj,
+    );
 
 The NumObj type constraint is provided by this library and accepts any object
 that is, or is derived from, a L<Data::Object::Number> object. The
@@ -807,7 +1023,10 @@ the argument can not be validated.
 
 =head2 NumObject
 
-    has data => (isa => NumObject);
+    has data => (
+        is  => 'rw',
+        isa => NumObject,
+    );
 
 The NumObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Number> object. The
@@ -817,7 +1036,10 @@ if the argument can not be validated.
 
 =head2 NumberObj
 
-    has data => (isa => NumberObj);
+    has data => (
+        is  => 'rw',
+        isa => NumberObj,
+    );
 
 The NumberObj type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Number> object. The
@@ -827,7 +1049,10 @@ if the argument can not be validated.
 
 =head2 NumberObject
 
-    has data => (isa => NumberObject);
+    has data => (
+        is  => 'rw',
+        isa => NumberObject,
+    );
 
 The NumberObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Number> object. The
@@ -837,7 +1062,10 @@ or false if the argument can not be validated.
 
 =head2 NumericCode
 
-    has data => (isa => NumericCode);
+    has data => (
+        is  => 'rw',
+        isa => NumericCode,
+    );
 
 The NumericCode type constraint is provided by the L<Types::Common::String>
 library. Please see that documentation for more information. The
@@ -847,7 +1075,10 @@ false if the argument can not be validated.
 
 =head2 Object
 
-    has data => (isa => Object);
+    has data => (
+        is  => 'rw',
+        isa => Object,
+    );
 
 The Object type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_Object> function
@@ -857,7 +1088,10 @@ be validated.
 
 =head2 OptList
 
-    has data => (isa => OptList);
+    has data => (
+        is  => 'rw',
+        isa => OptList,
+    );
 
 The OptList type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_OptList> function
@@ -867,7 +1101,10 @@ be validated.
 
 =head2 Optional
 
-    has data => (isa => Dict[id => Optional[Int]]);
+    has data => (
+        is  => 'rw',
+        isa => Dict[id => Optional[Int]],
+    );
 
 The Optional type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_Optional
@@ -877,7 +1114,10 @@ argument can not be validated.
 
 =head2 Overload
 
-    has data => (isa => Overload);
+    has data => (
+        is  => 'rw',
+        isa => Overload,
+    );
 
 The Overload type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_Overload
@@ -887,7 +1127,10 @@ argument can not be validated.
 
 =head2 Password
 
-    has data => (isa => Password);
+    has data => (
+        is  => 'rw',
+        isa => Password,
+    );
 
 The Password type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_Password
@@ -897,7 +1140,10 @@ argument can not be validated.
 
 =head2 PositiveInt
 
-    has data => (isa => PositiveInt);
+    has data => (
+        is  => 'rw',
+        isa => PositiveInt,
+    );
 
 The PositiveInt type constraint is provided by the L<Types::Common::Numeric>
 library. Please see that documentation for more information. The
@@ -907,7 +1153,10 @@ false if the argument can not be validated.
 
 =head2 PositiveNum
 
-    has data => (isa => PositiveNum);
+    has data => (
+        is  => 'rw',
+        isa => PositiveNum,
+    );
 
 The PositiveNum type constraint is provided by the L<Types::Common::Numeric>
 library. Please see that documentation for more information. The
@@ -917,7 +1166,10 @@ false if the argument can not be validated.
 
 =head2 PositiveOrZeroInt
 
-    has data => (isa => PositiveOrZeroInt);
+    has data => (
+        is  => 'rw',
+        isa => PositiveOrZeroInt,
+    );
 
 The PositiveOrZeroInt type constraint is provided by the
 L<Types::Common::Numeric> library. Please see that documentation for more The
@@ -928,7 +1180,10 @@ information.
 
 =head2 PositiveOrZeroNum
 
-    has data => (isa => PositiveOrZeroNum);
+    has data => (
+        is  => 'rw',
+        isa => PositiveOrZeroNum,
+    );
 
 The PositiveOrZeroNum type constraint is provided by the
 L<Types::Common::Numeric> library. Please see that documentation for more The
@@ -939,7 +1194,10 @@ information.
 
 =head2 Ref
 
-    has data => (isa => Ref['SCALAR']);
+    has data => (
+        is  => 'rw',
+        isa => Ref['SCALAR'],
+    );
 
 The Ref type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_type> function can be
@@ -949,7 +1207,10 @@ validated.
 
 =head2 RegexpObj
 
-    has data => (isa => RegexpObj);
+    has data => (
+        is  => 'rw',
+        isa => RegexpObj,
+    );
 
 The RegexpObj type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Regexp> object. The
@@ -959,7 +1220,10 @@ if the argument can not be validated.
 
 =head2 RegexpObject
 
-    has data => (isa => RegexpObject);
+    has data => (
+        is  => 'rw',
+        isa => RegexpObject,
+    );
 
 The RegexpObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Regexp> object. The
@@ -969,7 +1233,10 @@ or false if the argument can not be validated.
 
 =head2 RegexpRef
 
-    has data => (isa => RegexpRef);
+    has data => (
+        is  => 'rw',
+        isa => RegexpRef,
+    );
 
 The RegexpRef type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_RegexpRef
@@ -979,7 +1246,10 @@ argument can not be validated.
 
 =head2 RoleName
 
-    has data => (isa => RoleName);
+    has data => (
+        is  => 'rw',
+        isa => RoleName,
+    );
 
 The RoleName type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_RoleName
@@ -989,7 +1259,10 @@ argument can not be validated.
 
 =head2 ScalarObj
 
-    has data => (isa => ScalarObj);
+    has data => (
+        is  => 'rw',
+        isa => ScalarObj,
+    );
 
 The ScalarObj type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Scalar> object. The
@@ -999,7 +1272,10 @@ if the argument can not be validated.
 
 =head2 ScalarObject
 
-    has data => (isa => ScalarObject);
+    has data => (
+        is  => 'rw',
+        isa => ScalarObject,
+    );
 
 The ScalarObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Scalar> object. The
@@ -1009,7 +1285,10 @@ or false if the argument can not be validated.
 
 =head2 ScalarRef
 
-    has data => (isa => ScalarRef);
+    has data => (
+        is  => 'rw',
+        isa => ScalarRef,
+    );
 
 The ScalarRef type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_ScalarRef
@@ -1019,7 +1298,10 @@ argument can not be validated.
 
 =head2 SimpleStr
 
-    has data => (isa => SimpleStr);
+    has data => (
+        is  => 'rw',
+        isa => SimpleStr,
+    );
 
 The SimpleStr type constraint is provided by the L<Types::Common::String>
 library. Please see that documentation for more information. The
@@ -1029,7 +1311,10 @@ if the argument can not be validated.
 
 =head2 SingleDigit
 
-    has data => (isa => SingleDigit);
+    has data => (
+        is  => 'rw',
+        isa => SingleDigit,
+    );
 
 The SingleDigit type constraint is provided by the L<Types::Common::Numeric>
 library. Please see that documentation for more information. The
@@ -1039,7 +1324,10 @@ false if the argument can not be validated.
 
 =head2 Str
 
-    has data => (isa => Str);
+    has data => (
+        is  => 'rw',
+        isa => Str,
+    );
 
 The Str type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Str> function can be
@@ -1049,7 +1337,10 @@ validated.
 
 =head2 StrMatch
 
-    has data => (isa => StrMatch);
+    has data => (
+        is  => 'rw',
+        isa => StrMatch,
+    );
 
 The StrMatch type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_StrMatch
@@ -1059,7 +1350,10 @@ argument can not be validated.
 
 =head2 StrObj
 
-    has data => (isa => StrObj);
+    has data => (
+        is  => 'rw',
+        isa => StrObj,
+    );
 
 The StrObj type constraint is provided by this library and accepts any object
 that is, or is derived from, a L<Data::Object::String> object. The
@@ -1069,7 +1363,10 @@ the argument can not be validated.
 
 =head2 StrObject
 
-    has data => (isa => StrObject);
+    has data => (
+        is  => 'rw',
+        isa => StrObject,
+    );
 
 The StrObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::String> object. The
@@ -1079,7 +1376,10 @@ if the argument can not be validated.
 
 =head2 StrictNum
 
-    has data => (isa => StrictNum);
+    has data => (
+        is  => 'rw',
+        isa => StrictNum,
+    );
 
 The StrictNum type constraint is provided by the L<Types::Standard> library.
 Please see that documentation for more information. The C<assert_StrictNum
@@ -1089,7 +1389,10 @@ argument can not be validated.
 
 =head2 StringObj
 
-    has data => (isa => StringObj);
+    has data => (
+        is  => 'rw',
+        isa => StringObj,
+    );
 
 The StringObj type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::String> object. The
@@ -1099,7 +1402,10 @@ if the argument can not be validated.
 
 =head2 StringObject
 
-    has data => (isa => StringObject);
+    has data => (
+        is  => 'rw',
+        isa => StringObject,
+    );
 
 The StringObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::String> object. The
@@ -1109,7 +1415,10 @@ or false if the argument can not be validated.
 
 =head2 StrongPassword
 
-    has data => (isa => StrongPassword);
+    has data => (
+        is  => 'rw',
+        isa => StrongPassword,
+    );
 
 The StrongPassword type constraint is provided by the L<Types::Common::String>
 library. Please see that documentation for more information. The
@@ -1119,7 +1428,10 @@ return true or false if the argument can not be validated.
 
 =head2 Tied
 
-    has data => (isa => Tied['MyClass']);
+    has data => (
+        is  => 'rw',
+        isa => Tied['MyClass'],
+    );
 
 The Tied type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Tied> function can be
@@ -1129,7 +1441,10 @@ validated.
 
 =head2 Tuple
 
-    has data => (isa => Tuple[Int, Str, Str]);
+    has data => (
+        is  => 'rw',
+        isa => Tuple[Int, Str, Str],
+    );
 
 The Tuple type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Tuple> function can be
@@ -1139,7 +1454,10 @@ validated.
 
 =head2 Undef
 
-    has data => (isa => Undef);
+    has data => (
+        is  => 'rw',
+        isa => Undef,
+    );
 
 The Undef type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Undef> function can be
@@ -1149,7 +1467,10 @@ validated.
 
 =head2 UndefObj
 
-    has data => (isa => UndefObj);
+    has data => (
+        is  => 'rw',
+        isa => UndefObj,
+    );
 
 The UndefObj type constraint is provided by this library and accepts any object
 that is, or is derived from, a L<Data::Object::Undef> object. The
@@ -1159,7 +1480,10 @@ if the argument can not be validated.
 
 =head2 UndefObject
 
-    has data => (isa => UndefObject);
+    has data => (
+        is  => 'rw',
+        isa => UndefObject,
+    );
 
 The UndefObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Undef> object. The
@@ -1169,7 +1493,10 @@ false if the argument can not be validated.
 
 =head2 UniversalObj
 
-    has data => (isa => UniversalObj);
+    has data => (
+        is  => 'rw',
+        isa => UniversalObj,
+    );
 
 The UniversalObj type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Universal> object. The
@@ -1179,7 +1506,10 @@ or false if the argument can not be validated.
 
 =head2 UniversalObject
 
-    has data => (isa => UniversalObject);
+    has data => (
+        is  => 'rw',
+        isa => UniversalObject,
+    );
 
 The UniversalObject type constraint is provided by this library and accepts any
 object that is, or is derived from, a L<Data::Object::Universal> object. The
@@ -1189,7 +1519,10 @@ return true or false if the argument can not be validated.
 
 =head2 UpperCaseSimpleStr
 
-    has data => (isa => UpperCaseSimpleStr);
+    has data => (
+        is  => 'rw',
+        isa => UpperCaseSimpleStr,
+    );
 
 The UpperCaseSimpleStr type constraint is provided by the
 L<Types::Common::String> library. Please see that documentation for more The
@@ -1200,7 +1533,10 @@ information.
 
 =head2 UpperCaseStr
 
-    has data => (isa => UpperCaseStr);
+    has data => (
+        is  => 'rw',
+        isa => UpperCaseStr,
+    );
 
 The UpperCaseStr type constraint is provided by the L<Types::Common::String>
 library. Please see that documentation for more information. The C<assert_type
@@ -1210,7 +1546,10 @@ argument can not be validated.
 
 =head2 Value
 
-    has data => (isa => Value);
+    has data => (
+        is  => 'rw',
+        isa => Value,
+    );
 
 The Value type constraint is provided by the L<Types::Standard> library. Please
 see that documentation for more information. The C<assert_Value> function can be
