@@ -12,7 +12,7 @@ use Data::Object::Library;
 use Data::Object::Signatures;
 use Scalar::Util;
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 method eq ($arg1) {
 
@@ -64,11 +64,13 @@ Data::Object::Role::Alphabetic - Alphabetic Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Alphabetic;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Alphabetic';
 
 =head1 DESCRIPTION
 
