@@ -17,7 +17,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Item
 );
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 method all ($code, @args) {
 
@@ -674,11 +674,13 @@ Data::Object::Role::Array - Array Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Array;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Array';
 
 =head1 DESCRIPTION
 
