@@ -17,7 +17,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Item
 );
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 method call (@args) {
 
@@ -93,11 +93,13 @@ Data::Object::Role::Code - Code Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Code;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Code';
 
 =head1 DESCRIPTION
 
