@@ -30,7 +30,7 @@ requires 'set';
 requires 'slice';
 requires 'values';
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 1;
 
@@ -46,11 +46,13 @@ Data::Object::Role::Collection - Collection Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Collection;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Collection';
 
 =head1 DESCRIPTION
 
