@@ -19,7 +19,7 @@ requires 'lt';
 requires 'le';
 requires 'ne';
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 1;
 
@@ -35,11 +35,13 @@ Data::Object::Role::Comparison - Comparison Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Comparison;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Comparison';
 
 =head1 DESCRIPTION
 
