@@ -12,7 +12,7 @@ use Data::Object::Library;
 use Data::Object::Signatures;
 use Scalar::Util;
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 use overload (
     '0+'     => 'data',
@@ -49,11 +49,13 @@ Data::Object::Role::Detract - Detract Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Detract;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Detract';
 
 =head1 DESCRIPTION
 
