@@ -18,7 +18,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Value
 );
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 method defined () {
 
@@ -40,11 +40,13 @@ Data::Object::Role::Float - Float Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Float;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Float';
 
 =head1 DESCRIPTION
 
