@@ -19,7 +19,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Type
 );
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 1;
 
@@ -35,11 +35,13 @@ Data::Object::Role::Item - Item Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Item;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Item';
 
 =head1 DESCRIPTION
 
