@@ -18,7 +18,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Value
 );
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 method abs () {
 
@@ -124,11 +124,13 @@ Data::Object::Role::Number - Number Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Number;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Number';
 
 =head1 DESCRIPTION
 
