@@ -16,7 +16,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Dumper
 );
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 method print () {
 
@@ -48,11 +48,13 @@ Data::Object::Role::Output - Output Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Output;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Output';
 
 =head1 DESCRIPTION
 
