@@ -18,7 +18,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Value
 );
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 method append (@args) {
 
@@ -244,11 +244,13 @@ Data::Object::Role::String - String Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::String;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::String';
 
 =head1 DESCRIPTION
 
