@@ -12,7 +12,7 @@ use Data::Object::Library;
 use Data::Object::Signatures;
 use Scalar::Util;
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 my %METHODS;
 my %ROLES;
@@ -109,11 +109,13 @@ Data::Object::Role::Type - Type Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Type;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Type';
 
 =head1 DESCRIPTION
 
