@@ -17,7 +17,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Value
 );
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 method defined () {
 
@@ -75,11 +75,13 @@ Data::Object::Role::Undef - Undef Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Undef;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Undef';
 
 =head1 DESCRIPTION
 
