@@ -17,7 +17,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Value
 );
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 method defined () {
 
@@ -87,11 +87,13 @@ Data::Object::Role::Universal - Universal Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Universal;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Universal';
 
 =head1 DESCRIPTION
 
