@@ -17,7 +17,7 @@ map with($_), our @ROLES = qw(
     Data::Object::Role::Output
 );
 
-our $VERSION = '0.58'; # VERSION
+our $VERSION = '0.59'; # VERSION
 
 1;
 
@@ -33,11 +33,13 @@ Data::Object::Role::Value - Value Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
-    use Data::Object::Role::Value;
+    use Data::Object::Class;
+
+    with 'Data::Object::Role::Value';
 
 =head1 DESCRIPTION
 
